==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/cs.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Limit stahování souborů",
    "File link share download limit" : "Limit počtu stažení pro sdílení odkazem na soubor",
    "This app allows limiting the number of downloads for external link shares." : "Tato aplikace umožňuje omezovat počty stažení u sdílení externím odkazem.",
    "Limit downloads" : "Omezit stahování",
    "Set download limit" : "Nastavit limit pro stahování",
    "Setting a new limit will reset the download count" : "Nastavení nového limitu vrátí počet stažení na začátek",
    "The minimum limit is 1" : "Minimální limit je 1",
    "Failed to set download limit" : "Nepodařilo se nastavit limit počtu stažení",
    "Failed to remove download limit" : "Nepodařilo se odebrat limit počtu stažení",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["Zbývá 1 umožněné stažení","Zbývají {count} umožněná stažení","Zbývá {count} umožněných stažení","Zbývají {count} umožněná stažení"],
    "Download limit" : "Limit stahování",
    "Configure the default download limit for external shares." : "Nastavit výchozí limit počtu stahování pro externí sdílení.",
    "Set default download limit" : "Vyberte výchozí limit stahování",
    "Failed to set default download limit" : "Nepodařilo se nastavit limit počtu stahování",
    "You have reached the maximum amount of downloads allowed" : "Dosáhli jste nejvyššího umožněného počtu umožněných stažení",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Pro toto sdílení je omezen počet stahování. Opravdu chcete spustit nové stahování?"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/files_downloadlimit/l10n/cs.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Limit stahování souborů",
    "File link share download limit" : "Limit počtu stažení pro sdílení odkazem na soubor",
    "This app allows limiting the number of downloads for external link shares." : "Tato aplikace umožňuje omezovat počty stažení u sdílení externím odkazem.",
    "Limit downloads" : "Omezit stahování",
    "Set download limit" : "Nastavit limit pro stahování",
    "Setting a new limit will reset the download count" : "Nastavení nového limitu vrátí počet stažení na začátek",
    "The minimum limit is 1" : "Minimální limit je 1",
    "Failed to set download limit" : "Nepodařilo se nastavit limit počtu stažení",
    "Failed to remove download limit" : "Nepodařilo se odebrat limit počtu stažení",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["Zbývá 1 umožněné stažení","Zbývají {count} umožněná stažení","Zbývá {count} umožněných stažení","Zbývají {count} umožněná stažení"],
    "Download limit" : "Limit stahování",
    "Configure the default download limit for external shares." : "Nastavit výchozí limit počtu stahování pro externí sdílení.",
    "Set default download limit" : "Vyberte výchozí limit stahování",
    "Failed to set default download limit" : "Nepodařilo se nastavit limit počtu stahování",
    "You have reached the maximum amount of downloads allowed" : "Dosáhli jste nejvyššího umožněného počtu umožněných stažení",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Pro toto sdílení je omezen počet stahování. Opravdu chcete spustit nové stahování?",
    "Allow to limit the number of downloads for link shares" : "Umožňuje omezit počet stahování pro sdílení odkazem",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "Toto sdílení bylo omezeno na {limit} stažení. Pořád ještě zbývá {countLeft} umožněných."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
